Package 'spbtest5'

Title: Test Single Package Builder
Description: What the package does? (one paragraph).
Authors: Lori Shepherd [aut]
Maintainer: Lori Shepherd <[email protected]>
License: Artistic-2.0
Version: 0.99.1
Built: 2026-05-24 07:05:29 UTC
Source: https://github.com/Bioconductor/spbtest5

Help Index


A simple test function

Description

A simple test function. show link[ape]{drop.tip} %>%

Usage

test()
    test2()

Value

A logical TRUE

Examples

test()
    # workflow and data experiment get 4800 sec (80 min)
    # software times out after 10 min (600 sec)
    # package guideline for software is 5 min (300 sec)
    Sys.sleep(1)
    test2()

A whoami test function

Description

A simple test function.

Usage

whoami()

Value

The name of the package as a character string

Examples

myfunction <- function(){
        iam <- FALSE
    }
    myfunction()
    whoami()
    ## Not run: 
       # test a dontrun
       a = 1
    
## End(Not run)

A whoami test function

Description

A simple test function2.

Usage

whoami()

Value

The name of the package as a character string